==> perl-DateTime-Locale-1.22-1-src.tar.xz: DateTime-Locale-1.22/share/smn.pl <==
{
  am_pm_abbreviated => [
    "ip.",
    "ep.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E H.mm",
    EHms => "E H.mm.ss",
    Ed => "E d.",
    Ehm => "E h.mm a",
    Ehms => "E h.mm.ss a",
    Gy => "y G",
    GyMMM => "LLL y G",
    GyMMMEd => "E, MMM d. y G",
    GyMMMd => "MMM d. y G",
    H => "H",
    Hm => "H.mm",
    Hms => "H.mm.ss",
    Hmsv => "H.mm.ss v",
    Hmv => "H.mm v",
    M => "L",
    MEd => "E d.M.",
    MMM => "LLL",
    MMMEd => "E, MMM d.",
    "MMMMW-count-one" => "'okko' W, MMM",
    "MMMMW-count-other" => "'okko' W, MMM",
    "MMMMW-count-two" => "'okko' W, MMM",
    MMMMd => "MMMM d.",
    MMMd => "MMM d.",
    Md => "d.M.",
    d => "d",
    h => "h a",
    hm => "h.mm a",
    hms => "h.mm.ss a",
    hmsv => "h.mm.ss a v",
    hmv => "h.mm a v",
    ms => "m.ss.",
    y => "y",
    yM => "L.y",
    yMEd => "E d.M.y",
    yMMM => "LLL y",
    yMMMEd => "ccc, MMM d. y",
    yMMMM => "LLLL y",
    yMMMd => "MMM d. y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'okko' w, Y",
    "yw-count-other" => "'okko' w, Y",
    "yw-count-two" => "'okko' w, Y",
  },
  code => "smn",
  date_format_full => "cccc, MMMM d. y",
  date_format_long => "MMMM d. y",
  date_format_medium => "MMM d. y",
  date_format_short => "d.M.y",
  datetime_format_full => "{1} 'tme' {0}",
  datetime_format_long => "{1} 'tme' {0}",
  datetime_format_medium => "{1} 'tme' {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "vuo",
    "maj",
    "kos",
    "tuo",
    "v\N{U+00e1}s",
    "l\N{U+00e1}v",
    "pas",
  ],
  day_format_narrow => [
    "V",
    "M",
    "K",
    "T",
    "V",
    "L",
    "p",
  ],
  day_format_wide => [
    "vuossaarg\N{U+00e2}",
    "majebaarg\N{U+00e2}",
    "koskoho",
    "tuor\N{U+00e2}stuv",
    "v\N{U+00e1}stuppeeivi",
    "l\N{U+00e1}vurduv",
    "pasepeeivi",
  ],
  day_stand_alone_abbreviated => [
    "vuo",
    "maj",
    "kos",
    "tuo",
    "v\N{U+00e1}s",
    "l\N{U+00e1}v",
    "pas",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "vuossarg\N{U+00e2}",
    "majebarg\N{U+00e2}",
    "koskokko",
    "tuor\N{U+00e2}st\N{U+00e2}h",
    "v\N{U+00e1}stuppeivi",
    "l\N{U+00e1}vurd\N{U+00e2}h",
    "pasepeivi",
  ],
  era_abbreviated => [
    "oKr.",
    "mKr.",
  ],
  era_narrow => [
    "oKr.",
    "mKr.",
  ],
  era_wide => [
    "Ovdil Kristus \N{U+0161}odd\N{U+00e2}m",
    "ma\N{U+014b}a Kristus \N{U+0161}odd\N{U+00e2}m",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Inari Sami",
  month_format_abbreviated => [
    "u\N{U+0111}iv",
    "kuov\N{U+00e2}",
    "njuh\N{U+010d}\N{U+00e2}",
    "cu\N{U+00e1}\N{U+014b}ui",
    "vyesi",
    "kesi",
    "syeini",
    "porge",
    "\N{U+010d}oh\N{U+010d}\N{U+00e2}",
    "roovv\N{U+00e2}d",
    "skamm\N{U+00e2}",
    "juovl\N{U+00e2}",
  ],
  month_format_narrow => [
    "U",
    "K",
    "NJ",
    "C",
    "V",
    "K",
    "S",
    "P",
    "\N{U+010c}",
    "R",
    "S",
    "J",
  ],
  month_format_wide => [
    "u\N{U+0111}\N{U+0111}\N{U+00e2}ivem\N{U+00e1}\N{U+00e1}nu",
    "kuov\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "njuh\N{U+010d}\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "cu\N{U+00e1}\N{U+014b}uim\N{U+00e1}\N{U+00e1}nu",
    "vyesim\N{U+00e1}\N{U+00e1}nu",
    "kesim\N{U+00e1}\N{U+00e1}nu",
    "syeinim\N{U+00e1}\N{U+00e1}nu",
    "porgem\N{U+00e1}\N{U+00e1}nu",
    "\N{U+010d}oh\N{U+010d}\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "roovv\N{U+00e2}dm\N{U+00e1}\N{U+00e1}nu",
    "skamm\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "juovl\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
  ],
  month_stand_alone_abbreviated => [
    "u\N{U+0111}iv",
    "kuov\N{U+00e2}",
    "njuh\N{U+010d}\N{U+00e2}",
    "cu\N{U+00e1}\N{U+014b}ui",
    "vyesi",
    "kesi",
    "syeini",
    "porge",
    "\N{U+010d}oh\N{U+010d}\N{U+00e2}",
    "roovv\N{U+00e2}d",
    "skamm\N{U+00e2}",
    "juovl\N{U+00e2}",
  ],
  month_stand_alone_narrow => [
    "U",
    "K",
    "NJ",
    "C",
    "V",
    "K",
    "S",
    "P",
    "\N{U+010c}",
    "R",
    "S",
    "J",
  ],
  month_stand_alone_wide => [
    "u\N{U+0111}\N{U+0111}\N{U+00e2}ivem\N{U+00e1}\N{U+00e1}nu",
    "kuov\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "njuh\N{U+010d}\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "cu\N{U+00e1}\N{U+014b}uim\N{U+00e1}\N{U+00e1}nu",
    "vyesim\N{U+00e1}\N{U+00e1}nu",
    "kesim\N{U+00e1}\N{U+00e1}nu",
    "syeinim\N{U+00e1}\N{U+00e1}nu",
    "porgem\N{U+00e1}\N{U+00e1}nu",
    "\N{U+010d}oh\N{U+010d}\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "roovv\N{U+00e2}dm\N{U+00e1}\N{U+00e1}nu",
    "skamm\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "juovl\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
  ],
  name => "Inari Sami",
  native_language => "anar\N{U+00e2}\N{U+0161}kiel\N{U+00e2}",
  native_name => "anar\N{U+00e2}\N{U+0161}kiel\N{U+00e2}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. ni\N{U+00e4}lj.",
    "2. ni\N{U+00e4}lj.",
    "3. ni\N{U+00e4}lj.",
    "4. ni\N{U+00e4}lj.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
    "2. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
    "3. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
    "4. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
  ],
  quarter_stand_alone_abbreviated => [
    "1. ni\N{U+00e4}lj.",
    "2. ni\N{U+00e4}lj.",
    "3. ni\N{U+00e4}lj.",
    "4. ni\N{U+00e4}lj.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
    "2. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
    "3. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
    "4. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
  ],
  script => undef,
  territory => undef,
  time_format_full => "H.mm.ss zzzz",
  time_format_long => "H.mm.ss z",
  time_format_medium => "H.mm.ss",
  time_format_short => "H.mm",
  variant => undef,
  version => 33,
}

==> perl-DateTime-Locale-1.24-1-src.tar.xz: DateTime-Locale-1.24/share/smn.pl <==
{
  am_pm_abbreviated => [
    "ip.",
    "ep.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E H.mm",
    EHms => "E H.mm.ss",
    Ed => "E d.",
    Ehm => "E h.mm a",
    Ehms => "E h.mm.ss a",
    Gy => "y G",
    GyMMM => "LLL y G",
    GyMMMEd => "E, MMM d. y G",
    GyMMMd => "MMM d. y G",
    H => "H",
    Hm => "H.mm",
    Hms => "H.mm.ss",
    Hmsv => "H.mm.ss v",
    Hmv => "H.mm v",
    M => "L",
    MEd => "E d.M.",
    MMM => "LLL",
    MMMEd => "E, MMM d.",
    "MMMMW-count-one" => "'okko' W, MMMM",
    "MMMMW-count-other" => "'okko' W, MMMM",
    "MMMMW-count-two" => "'okko' W, MMMM",
    MMMMd => "MMMM d.",
    MMMd => "MMM d.",
    Md => "d.M.",
    d => "d",
    h => "h a",
    hm => "h.mm a",
    hms => "h.mm.ss a",
    hmsv => "h.mm.ss a v",
    hmv => "h.mm a v",
    ms => "m.ss.",
    y => "y",
    yM => "L.y",
    yMEd => "E d.M.y",
    yMMM => "LLL y",
    yMMMEd => "ccc, MMM d. y",
    yMMMM => "LLLL y",
    yMMMd => "MMM d. y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'okko' w, Y",
    "yw-count-other" => "'okko' w, Y",
    "yw-count-two" => "'okko' w, Y",
  },
  code => "smn",
  date_format_full => "cccc, MMMM d. y",
  date_format_long => "MMMM d. y",
  date_format_medium => "MMM d. y",
  date_format_short => "d.M.y",
  datetime_format_full => "{1} 'tme' {0}",
  datetime_format_long => "{1} 'tme' {0}",
  datetime_format_medium => "{1} 'tme' {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "vuo",
    "maj",
    "kos",
    "tuo",
    "v\N{U+00e1}s",
    "l\N{U+00e1}v",
    "pas",
  ],
  day_format_narrow => [
    "V",
    "M",
    "K",
    "T",
    "V",
    "L",
    "p",
  ],
  day_format_wide => [
    "vuossaarg\N{U+00e2}",
    "majebaarg\N{U+00e2}",
    "koskoho",
    "tuor\N{U+00e2}stuv",
    "v\N{U+00e1}stuppeeivi",
    "l\N{U+00e1}vurduv",
    "pasepeeivi",
  ],
  day_stand_alone_abbreviated => [
    "vuo",
    "maj",
    "kos",
    "tuo",
    "v\N{U+00e1}s",
    "l\N{U+00e1}v",
    "pas",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "vuossarg\N{U+00e2}",
    "majebarg\N{U+00e2}",
    "koskokko",
    "tuor\N{U+00e2}st\N{U+00e2}h",
    "v\N{U+00e1}stuppeivi",
    "l\N{U+00e1}vurd\N{U+00e2}h",
    "pasepeivi",
  ],
  era_abbreviated => [
    "oKr.",
    "mKr.",
  ],
  era_narrow => [
    "oKr.",
    "mKr.",
  ],
  era_wide => [
    "Ovdil Kristus \N{U+0161}odd\N{U+00e2}m",
    "ma\N{U+014b}a Kristus \N{U+0161}odd\N{U+00e2}m",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Inari Sami",
  month_format_abbreviated => [
    "u\N{U+0111}iv",
    "kuov\N{U+00e2}",
    "njuh\N{U+010d}\N{U+00e2}",
    "cu\N{U+00e1}\N{U+014b}ui",
    "vyesi",
    "kesi",
    "syeini",
    "porge",
    "\N{U+010d}oh\N{U+010d}\N{U+00e2}",
    "roovv\N{U+00e2}d",
    "skamm\N{U+00e2}",
    "juovl\N{U+00e2}",
  ],
  month_format_narrow => [
    "U",
    "K",
    "NJ",
    "C",
    "V",
    "K",
    "S",
    "P",
    "\N{U+010c}",
    "R",
    "S",
    "J",
  ],
  month_format_wide => [
    "u\N{U+0111}\N{U+0111}\N{U+00e2}ivem\N{U+00e1}\N{U+00e1}nu",
    "kuov\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "njuh\N{U+010d}\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "cu\N{U+00e1}\N{U+014b}uim\N{U+00e1}\N{U+00e1}nu",
    "vyesim\N{U+00e1}\N{U+00e1}nu",
    "kesim\N{U+00e1}\N{U+00e1}nu",
    "syeinim\N{U+00e1}\N{U+00e1}nu",
    "porgem\N{U+00e1}\N{U+00e1}nu",
    "\N{U+010d}oh\N{U+010d}\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "roovv\N{U+00e2}dm\N{U+00e1}\N{U+00e1}nu",
    "skamm\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "juovl\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
  ],
  month_stand_alone_abbreviated => [
    "u\N{U+0111}iv",
    "kuov\N{U+00e2}",
    "njuh\N{U+010d}\N{U+00e2}",
    "cu\N{U+00e1}\N{U+014b}ui",
    "vyesi",
    "kesi",
    "syeini",
    "porge",
    "\N{U+010d}oh\N{U+010d}\N{U+00e2}",
    "roovv\N{U+00e2}d",
    "skamm\N{U+00e2}",
    "juovl\N{U+00e2}",
  ],
  month_stand_alone_narrow => [
    "U",
    "K",
    "NJ",
    "C",
    "V",
    "K",
    "S",
    "P",
    "\N{U+010c}",
    "R",
    "S",
    "J",
  ],
  month_stand_alone_wide => [
    "u\N{U+0111}\N{U+0111}\N{U+00e2}ivem\N{U+00e1}\N{U+00e1}nu",
    "kuov\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "njuh\N{U+010d}\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "cu\N{U+00e1}\N{U+014b}uim\N{U+00e1}\N{U+00e1}nu",
    "vyesim\N{U+00e1}\N{U+00e1}nu",
    "kesim\N{U+00e1}\N{U+00e1}nu",
    "syeinim\N{U+00e1}\N{U+00e1}nu",
    "porgem\N{U+00e1}\N{U+00e1}nu",
    "\N{U+010d}oh\N{U+010d}\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "roovv\N{U+00e2}dm\N{U+00e1}\N{U+00e1}nu",
    "skamm\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
    "juovl\N{U+00e2}m\N{U+00e1}\N{U+00e1}nu",
  ],
  name => "Inari Sami",
  native_language => "anar\N{U+00e2}\N{U+0161}kiel\N{U+00e2}",
  native_name => "anar\N{U+00e2}\N{U+0161}kiel\N{U+00e2}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. ni\N{U+00e4}lj.",
    "2. ni\N{U+00e4}lj.",
    "3. ni\N{U+00e4}lj.",
    "4. ni\N{U+00e4}lj.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
    "2. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
    "3. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
    "4. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
  ],
  quarter_stand_alone_abbreviated => [
    "1. ni\N{U+00e4}lj.",
    "2. ni\N{U+00e4}lj.",
    "3. ni\N{U+00e4}lj.",
    "4. ni\N{U+00e4}lj.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
    "2. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
    "3. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
    "4. ni\N{U+00e4}lj\N{U+00e1}d\N{U+00e2}s",
  ],
  script => undef,
  territory => undef,
  time_format_full => "H.mm.ss zzzz",
  time_format_long => "H.mm.ss z",
  time_format_medium => "H.mm.ss",
  time_format_short => "H.mm",
  variant => undef,
  version => 35,
}
